@@ -71,11 +71,13 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
     ylabs <- opz$ylab
     if (length(ylabs) <= 0)
         ylabs <- paste("Effect  of ", term, sep = " ")
+    
+    
     #a <- intercept(x, term, gap = show.gap)[[1]][, "Est."]
-    a <- intercept(x, term)[[1]][, "Est."]
+    a <- intercept(x, term, digits=20)[[1]][, "Est."]
     #Poiche' intercept() restituisce quantita' che includono sempre l'intercetta del modello, questa va eliminata se interc=FALSE
     if(!interc && ("(Intercept)" %in% names(coef(x)))) a<- a-coef(x)["(Intercept)"]
-    b <- slope(x, term)[[1]][, "Est."]
+    b <- slope(x, term, digits=20)[[1]][, "Est."]
     
     #id <- grep(paste("\\.", term, "$", sep = ""), rownames(x$psi), value = FALSE) #confondeva "psi1.x","psi1.neg.x"
     id <- f.U(rownames(x$psi), term)
@@ -139,6 +141,7 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
 #        xout <- sort(c(seq(val[1], val[length(val)], l = 150), val[-c(1, length(val))]))
         xout <- sort(c(seq(val[1], val[length(val)], l = 150), val[-c(1, length(val))],val[-c(1, length(val))]*1.005))
         l <- approx(as.vector(m[, c(1, 3)]), as.vector(m[, c(2, 4)]), xout = xout)
+        val[length(val)]<-max(l$x) #aggiunto 11/09/17
         id.group <- cut(l$x, val, FALSE, TRUE)
         yhat <- l$y
         xhat <- l$x
@@ -147,6 +150,8 @@ plot.segmented<-function (x, term, add = FALSE, res = FALSE, conf.level = 0,
             plot(as.vector(m[, c(1, 3)]), as.vector(m[, c(2,
                 4)]), type = "n", xlab = xlabs, ylab = ylabs,
                 main = opz$main, sub = opz$sub, 
+                cex.axis = opz$cex.axis,
+                cex.lab = opz$cex.lab,
                 xlim = opz$xlim,
                 ylim = if(is.null(opz$ylim)) enl.range(fit, rangeCI, enlarge=dens.rug) else opz$ylim )
         if(dens.rug){
